#ifndef MOUSE_H
#define MOUSE_H

#include "../common/sources/system/cmaths.h"
#include "../common/sources/Map.h"
#include <vector>
#include <QImage>

enum EMouseAreaTypes
{
    eMouseArea_None = 0,

    // interface areas
    eMouseArea_Inventory,
    eMouseArea_3DView,
    eMouseArea_Resurrect,
    eMouseArea_Eye,
    eMouseArea_ArrowForward,
    eMouseArea_ArrowBackward,
    eMouseArea_ArrowLeft,
    eMouseArea_ArrowRight,
    eMouseArea_ArrowTurnLeft,
    eMouseArea_ArrowTurnRight,
    eMouseArea_InvObject,
    eMouseArea_SelectChamp,

    // game areas
    eMouseAreaG_Champion,
    eMouseAreaG_DoorButton,
    eMouseAreaG_PickObject,
    eMouseAreaG_DropObject
};

enum ECursorTypes
{
    eCursor_None = 0,
    eCursor_Arrow,
    eCursor_Hand
};

struct SMouseArea
{
    EMouseAreaTypes type;
    CRect           rect;
    void*           param1;
    void*           param2;
    ECursorTypes    cursor;
};

class CMouse
{
public:
    CMouse();

    void        update();
    void        clearAreas();
    void        addArea(EMouseAreaTypes type, CRect rect, ECursorTypes cursor = eCursor_Arrow, void* param1 = NULL, void* param2 = NULL);
    SMouseArea* clickedArea(QImage *image);

    CVec2   mPos;
    bool    mButtonPressed;
    bool    mButtonPressing;
    bool    mButtonReleasing;
    CObject mObjectInHand;

private:
    std::vector<SMouseArea>   mAreaList;
};

extern CMouse  mouse;

#endif // MOUSE_H
